# WARNING: Synchronized with Fedora!

# Provide backport definitions stuff
%{!?__python2: %global __python2 %{__python}}
%{!?python2_sitelib: %global python2_sitelib %{python_sitelib}}

# Mageia does not currently have a Koji instance
# available on its infrastructure yet, so for now,
# the patch for using it with the koji CLI client is
# disabled. (ngompa)
%bcond_with use_mga_cli_cfg

Name: koji
Version: 1.12.0
Release: %mkrel 2
License: LGPLv2 and GPLv2+
# koji.ssl libs (from plague) are GPLv2+
Summary: Build system tools
Group: System/Packaging
URL: https://koji.build/

Source: https://releases.pagure.org/%{name}/%{name}-%{version}.tar.bz2

# Backports from upstream
Patch0001: 0001-allow-kojid-to-start-when-not-using-ssl-cert-auth.patch

# Mageia-specific patches
# Switch default to use createrepo_c
Patch1000: mageia-koji-builder-config.patch
# Set up defaults for the Koji CLI client
Patch1001: mageia-koji-cli-config.patch

BuildArch: noarch
# No longer mandatory, as python-requests-kerberos (GSSAPI) is preferred
Recommends: python-krbV >= 1.0.13
Requires: python-rpm
Requires: python-OpenSSL
Requires: python-requests
Requires: python-requests-kerberos
Requires: python-urlgrabber
Requires: python-dateutil
Requires: yum
BuildRequires: python2-devel
BuildRequires: python-sphinx
BuildRequires: systemd-devel
BuildRequires: pkgconfig
Requires: python-libcomps

%description
Koji is a system for building and tracking RPMS.  The base package
contains shared libraries and the command-line interface.

%package hub
Summary: Koji XMLRPC interface
Group: System/Servers
License: LGPLv2 and GPLv2
# rpmdiff lib (from rpmlint) is GPLv2 (only)
Requires: apache
Requires: apache-mod_wsgi
Requires: python-psycopg2
Requires: %{name} = %{version}-%{release}

%description hub
koji-hub is the XMLRPC interface to the koji database

%package hub-plugins
Summary: Koji hub plugins
Group: System/Servers
License: LGPLv2
Requires: %{name} = %{version}-%{release}
Requires: %{name}-hub = %{version}-%{release}
Requires: python-qpid >= 0.7
# (ngompa): Cannot get qpid-proton to build
#Requires: python-qpid-proton
Requires: cpio

%description hub-plugins
Plugins to the koji XMLRPC interface

%package builder
Summary: Koji RPM builder daemon
Group: System/Packaging
License: LGPLv2 and GPLv2+
#mergerepos (from createrepo) is GPLv2+
Requires: %{name} = %{version}-%{release}
Requires: mock >= 0.9.14
Requires(pre): shadow-utils
Requires: squashfs-tools
Requires: python2-multilib
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

Requires: cvs
Requires: subversion
Requires: git-core
Requires: python-cheetah
Requires: createrepo >= 0.9.2
# We use createrepo_c by default (per Patch 1000)
Requires: createrepo_c

%description builder
koji-builder is the daemon that runs on build machines and executes
tasks that come through the Koji system.

%package vm
Summary: Koji virtual machine management daemon
Group: System/Servers
License: LGPLv2
Requires: %{name} = %{version}-%{release}

Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

Requires: python-libvirt
Requires: libxml2-python
Requires: virt-clone
Requires: qemu-img

%description vm
koji-vm contains a supplemental build daemon that executes certain tasks in a
virtual machine. This package is not required for most installations.

%package utils
Summary: Koji Utilities
Group: System/Packaging
License: LGPLv2
Requires: python-psycopg2
Requires: %{name} = %{version}-%{release}

Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%description utils
Utilities for the Koji system

%package web
Summary: Koji Web UI
Group: System/Servers
License: LGPLv2
Requires: apache
Requires: apache-mod_wsgi
Requires: apache-mod_auth_kerb
Requires: python-psycopg2
Requires: python-cheetah
Requires: %{name} = %{version}-%{release}
# No longer mandatory, as python-requests-kerberos (GSSAPI) is preferred
Recommends: python-krbV >= 1.0.13

%description web
koji-web is a web UI to the Koji system.

%prep
%setup -q

%patch1000 -p1 -b .orig-builder~
%if %{with use_mga_cli_cfg}
%patch1001 -p1 -b .orig-cli~
%endif


%build
# Nothing to build

%install
%make_install


%files
%defattr(-,root,root)
%{_bindir}/*
%{python2_sitelib}/%{name}
%config(noreplace) %{_sysconfdir}/koji.conf
%dir %{_sysconfdir}/koji.conf.d
%doc docs Authors
%license COPYING LGPL

%files hub
%defattr(-,root,root)
%{_datadir}/koji-hub
%dir %{_libexecdir}/koji-hub
%{_libexecdir}/koji-hub/rpmdiff
%config(noreplace) %{_sysconfdir}/httpd/conf.d/kojihub.conf
%dir %{_sysconfdir}/koji-hub
%config(noreplace) %{_sysconfdir}/koji-hub/hub.conf
%dir %{_sysconfdir}/koji-hub/hub.conf.d

%files hub-plugins
%defattr(-,root,root)
%dir %{_prefix}/lib/koji-hub-plugins
%{_prefix}/lib/koji-hub-plugins/*.py*
%dir %{_sysconfdir}/koji-hub/plugins
%{_sysconfdir}/koji-hub/plugins/*.conf
# (ngompa): Cannot get qpid-proton to build
%exclude %{_prefix}/lib/koji-hub-plugins/protonmsg*
%exclude %{_sysconfdir}/koji-hub/plugins/protonmsg*

%files utils
%defattr(-,root,root)
%{_sbindir}/kojira
%{_unitdir}/kojira.service
%dir %{_sysconfdir}/kojira
%config(noreplace) %{_sysconfdir}/kojira/kojira.conf
%{_sbindir}/koji-gc
%dir %{_sysconfdir}/koji-gc
%config(noreplace) %{_sysconfdir}/koji-gc/koji-gc.conf
%{_sbindir}/koji-shadow
%dir %{_sysconfdir}/koji-shadow
%config(noreplace) %{_sysconfdir}/koji-shadow/koji-shadow.conf

%files web
%defattr(-,root,root)
%{_datadir}/koji-web
%dir %{_sysconfdir}/kojiweb
%config(noreplace) %{_sysconfdir}/kojiweb/web.conf
%config(noreplace) %{_sysconfdir}/httpd/conf.d/kojiweb.conf
%dir %{_sysconfdir}/kojiweb/web.conf.d

%files builder
%defattr(-,root,root)
%{_sbindir}/kojid
%dir %{_libexecdir}/kojid
%{_libexecdir}/kojid/mergerepos
%defattr(-,root,root)
%dir %{_prefix}/lib/koji-builder-plugins
%{_prefix}/lib/koji-builder-plugins/*.py*
%{_unitdir}/kojid.service
%dir %{_sysconfdir}/kojid
%config(noreplace) %{_sysconfdir}/kojid/kojid.conf
%dir %{_sysconfdir}/kojid/plugins
%config(noreplace) %{_sysconfdir}/kojid/plugins/runroot.conf
%config(noreplace) %{_sysconfdir}/kojid/plugins/save_failed_tree.conf
%attr(-,kojibuilder,kojibuilder) %{_sysconfdir}/mock/koji

%pre builder
/usr/sbin/useradd -r -s /bin/bash -G mock -d /builddir -M kojibuilder 2>/dev/null ||:

%post builder
%systemd_post kojid.service

%preun builder
%systemd_preun kojid.service



%files vm
%defattr(-,root,root)
%{_sbindir}/kojivmd
%dir %{_datadir}/kojivmd
%{_datadir}/kojivmd/kojikamid
%{_unitdir}/kojivmd.service
%dir %{_sysconfdir}/kojivmd
%config(noreplace) %{_sysconfdir}/kojivmd/kojivmd.conf

%post vm
%systemd_post kojivmd.service

%preun vm
%systemd_preun kojivmd.service



%post utils
%systemd_post kojira.service

%preun utils
%systemd_preun kojira.service





%changelog
* Sun May 14 2017 ngompa <ngompa> 1.12.0-2.mga6
+ Revision: 1101048
- Backport patch for kojid for non-SSL auth

* Wed Apr 19 2017 ngompa <ngompa> 1.12.0-1.mga6
+ Revision: 1096749
- Upgrade to v1.12.0
- Drop merged patches
- Move Mageia configuration patches to the end for easier rebasing

* Sat Dec 17 2016 ngompa <ngompa> 1.11.0-3.mga6
+ Revision: 1075744
- Fix broken Requires (shadowutils->shadow-utils)

* Fri Dec 16 2016 ngompa <ngompa> 1.11.0-2.mga6
+ Revision: 1075735
- Downgrading python-krbV dependency to Recommends, as it's a fallback mechanism now

* Mon Dec 12 2016 ngompa <ngompa> 1.11.0-1.mga6
+ Revision: 1074306
- Update to koji 1.11.0
- Add patch to enable picking up username from krb ticket
- Add patch to convert from PyGreSQL to psycopg2

* Sun May 08 2016 ngompa <ngompa> 1.10.1-9.mga6
+ Revision: 1011004
- imported package koji

